<?php
/**
 * Customizer active callbacks
 *
 * @package Theme Palace
 * @subpackage Magazinews Pro
 * @since Magazinews Pro 1.0.0
 */

if ( ! function_exists( 'magazinews_pro_is_loader_enable' ) ) :
	/**
	 * Check if loader is enabled.
	 *
	 * @since Magazinews Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function magazinews_pro_is_loader_enable( $control ) {
		return $control->manager->get_setting( 'magazinews_pro_theme_options[loader_enable]' )->value();
	}
endif;

if ( ! function_exists( 'magazinews_pro_is_breadcrumb_enable' ) ) :
	/**
	 * Check if breadcrumb is enabled.
	 *
	 * @since Magazinews Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function magazinews_pro_is_breadcrumb_enable( $control ) {
		return $control->manager->get_setting( 'magazinews_pro_theme_options[breadcrumb_enable]' )->value();
	}
endif;

if ( ! function_exists( 'magazinews_pro_is_pagination_enable' ) ) :
	/**
	 * Check if pagination is enabled.
	 *
	 * @since Magazinews Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function magazinews_pro_is_pagination_enable( $control ) {
		return $control->manager->get_setting( 'magazinews_pro_theme_options[pagination_enable]' )->value();
	}
endif;

/**
 * Front Page Active Callbacks
 */

/**
 * Check if topbar section is enabled.
 *
 * @since Magazinews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazinews_pro_is_topbar_section_enable( $control ) {
	return ( $control->manager->get_setting( 'magazinews_pro_theme_options[topbar_section_enable]' )->value() );
}

/**
 * Check if headline section is enabled.
 *
 * @since Magazinews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazinews_pro_is_headline_section_enable( $control ) {
	return ( $control->manager->get_setting( 'magazinews_pro_theme_options[headline_section_enable]' )->value() );
}

/**
 * Check if headline section content type is category.
 *
 * @since Magazinews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazinews_pro_is_headline_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'magazinews_pro_theme_options[headline_content_type]' )->value();
	return magazinews_pro_is_headline_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if headline section content type is page.
 *
 * @since Magazinews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazinews_pro_is_headline_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'magazinews_pro_theme_options[headline_content_type]' )->value();
	return magazinews_pro_is_headline_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if headline section content type is post.
 *
 * @since Magazinews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazinews_pro_is_headline_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'magazinews_pro_theme_options[headline_content_type]' )->value();
	return magazinews_pro_is_headline_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if slider section is enabled.
 *
 * @since Magazinews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazinews_pro_is_slider_section_enable( $control ) {
	return ( $control->manager->get_setting( 'magazinews_pro_theme_options[slider_section_enable]' )->value() );
}

/**
 * Check if slider section content type is category.
 *
 * @since Magazinews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazinews_pro_is_slider_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'magazinews_pro_theme_options[slider_content_type]' )->value();
	return magazinews_pro_is_slider_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if slider section content type is page.
 *
 * @since Magazinews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazinews_pro_is_slider_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'magazinews_pro_theme_options[slider_content_type]' )->value();
	return magazinews_pro_is_slider_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if slider section content type is post.
 *
 * @since Magazinews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazinews_pro_is_slider_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'magazinews_pro_theme_options[slider_content_type]' )->value();
	return magazinews_pro_is_slider_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if featured section is enabled.
 *
 * @since Magazinews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazinews_pro_is_featured_section_enable( $control ) {
	return ( $control->manager->get_setting( 'magazinews_pro_theme_options[featured_section_enable]' )->value() );
}

/**
 * Check if editor_choice section is enabled.
 *
 * @since Magazinews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazinews_pro_is_editor_choice_section_enable( $control ) {
	return ( $control->manager->get_setting( 'magazinews_pro_theme_options[editor_choice_section_enable]' )->value() );
}

/**
 * Check if popular section is enabled.
 *
 * @since Magazinews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazinews_pro_is_popular_section_enable( $control ) {
	return ( $control->manager->get_setting( 'magazinews_pro_theme_options[popular_section_enable]' )->value() );
}

/**
 * Check if trending section is enabled.
 *
 * @since Magazinews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazinews_pro_is_trending_section_enable( $control ) {
	return ( $control->manager->get_setting( 'magazinews_pro_theme_options[trending_section_enable]' )->value() );
}

/**
 * Check if featured_story section is enabled.
 *
 * @since Magazinews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazinews_pro_is_featured_story_section_enable( $control ) {
	return ( $control->manager->get_setting( 'magazinews_pro_theme_options[featured_story_section_enable]' )->value() );
}

/**
 * Check if featured_story section content type is category.
 *
 * @since Magazinews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazinews_pro_is_featured_story_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'magazinews_pro_theme_options[featured_story_content_type]' )->value();
	return magazinews_pro_is_featured_story_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if featured_story section content type is page.
 *
 * @since Magazinews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazinews_pro_is_featured_story_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'magazinews_pro_theme_options[featured_story_content_type]' )->value();
	return magazinews_pro_is_featured_story_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if featured_story section content type is post.
 *
 * @since Magazinews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazinews_pro_is_featured_story_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'magazinews_pro_theme_options[featured_story_content_type]' )->value();
	return magazinews_pro_is_featured_story_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if author_collection section is enabled.
 *
 * @since Magazinews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazinews_pro_is_author_collection_section_enable( $control ) {
	return ( $control->manager->get_setting( 'magazinews_pro_theme_options[author_collection_section_enable]' )->value() );
}

/**
 * Check if author_collection section content type is category.
 *
 * @since Magazinews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazinews_pro_is_author_collection_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'magazinews_pro_theme_options[author_collection_content_type]' )->value();
	return magazinews_pro_is_author_collection_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if author_collection section content type is page.
 *
 * @since Magazinews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazinews_pro_is_author_collection_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'magazinews_pro_theme_options[author_collection_content_type]' )->value();
	return magazinews_pro_is_author_collection_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if author_collection section content type is post.
 *
 * @since Magazinews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazinews_pro_is_author_collection_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'magazinews_pro_theme_options[author_collection_content_type]' )->value();
	return magazinews_pro_is_author_collection_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if gallery section is enabled.
 *
 * @since Magazinews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazinews_pro_is_gallery_section_enable( $control ) {
	return ( $control->manager->get_setting( 'magazinews_pro_theme_options[gallery_section_enable]' )->value() );
}

/**
 * Check if blog section is enabled.
 *
 * @since Magazinews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazinews_pro_is_blog_section_enable( $control ) {
	return ( $control->manager->get_setting( 'magazinews_pro_theme_options[blog_section_enable]' )->value() );
}

/**
 * Check if blog section content type is post.
 *
 * @since Magazinews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazinews_pro_is_blog_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'magazinews_pro_theme_options[blog_content_type]' )->value();
	return magazinews_pro_is_blog_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if blog section content type is page.
 *
 * @since Magazinews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazinews_pro_is_blog_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'magazinews_pro_theme_options[blog_content_type]' )->value();
	return magazinews_pro_is_blog_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if blog section content type is category.
 *
 * @since Magazinews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazinews_pro_is_blog_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'magazinews_pro_theme_options[blog_content_type]' )->value();
	return magazinews_pro_is_blog_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if blog section content type is recent.
 *
 * @since Magazinews Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function magazinews_pro_is_blog_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'magazinews_pro_theme_options[blog_content_type]' )->value();
	return magazinews_pro_is_blog_section_enable( $control ) && ( 'recent' == $content_type );
}
